====================
Materia Utils Module
====================

.. begin-description

.. image:: https://codecov.io/gh/kijanac/materia-utils/branch/master/graph/badge.svg
  :target: https://codecov.io/gh/kijanac/materia-utils

.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
    :target: https://github

**Lightweight utilities for atomistic simulations of materials.**

Utilities for atomistic simulations of materials through Materia.

.. end-description

---------------
Getting Started
---------------

Installing
----------
.. begin-installing

From `pip <https://pypi.org/project/materia-utils/>`_:

``pip install materia-utils``

From `conda <https://anaconda.org/kijana/materia-utils>`_:

``conda install -c conda-forge -c kijana materia-utils``

.. end-installing

Documentation
-------------
See documentation `here <https://kijanac.github.io/materia-utils/>`_.

Examples
--------
See example scripts in `Examples <https://github.com/kijanac/materia-utils/tree/main/examples>`_.

.. begin-about

-------
Authors
-------
Ki-Jana Carter

-------
License
-------
This project is licensed under the MIT License - see the `LICENSE <https://github.com/kijanac/materia-utils/blob/main/LICENSE>`_ file for details.

.. end-about

.. begin-contributing

------------
Contributing
------------
See `CONTRIBUTING <https://github.com/kijanac/materia-utils/blob/main/CONTRIBUTING.rst>`_.

.. end-contributing